==> zhongyan-manage-service-api-3.0.27-sources.jar: cn/com/duiba/cloud/manage/service/api/config/TenantProperties.java <==
package cn.com.duiba.cloud.manage.service.api.config;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

/**
 * @author yuanzhixin
 * @version 1.0
 * @description 企业默认配置
 * @date 2021/11/25 15:58
 */
@Component
@ConfigurationProperties(prefix = "zhongyan.tenant.default")
public class TenantProperties {

    /**
     * 企业id
     */
    public static Long tenantId = 111L;

    /**
     * 企业名称
     */
    public static String name = "浙江中烟";

    /**
     * 注册日期
     */
    public static String signDate = "2021-01-01";

    /**
     * 默认密码
     */
    public static String password = "zhongyan123";

    /**
     * 登录cookie秘钥
     */
    public static String keyEncrypt = "lxk5vo1dndcz";

    /**
     * cookie名称
     */
    public static String cookieName = "manage-tku";

    /**
     * 一级域名
     */
    public static String domain = "";

    public void setTenantId(Long tenantId) {
        TenantProperties.tenantId = tenantId;
    }

    public void setName(String name) {
        TenantProperties.name = name;
    }

    public void setSignDate(String signDate) {
        TenantProperties.signDate = signDate;
    }

    public void setPassword(String password) {
        TenantProperties.password = password;
    }

    public void setKeyEncrypt(String keyEncrypt) {
        TenantProperties.keyEncrypt = keyEncrypt;
    }

    public void setCookieName(String cookieName) {
        TenantProperties.cookieName = cookieName;
    }

    public void setDomain(String domain) {
        TenantProperties.domain = domain;
    }
}

==> zhongyan-manage-service-api-3.0.45-sources.jar: cn/com/duiba/cloud/manage/service/api/config/TenantProperties.java <==
package cn.com.duiba.cloud.manage.service.api.config;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

/**
 * @author yuanzhixin
 * @version 1.0
 * @description 企业默认配置
 * @date 2021/11/25 15:58
 */
@Component
@ConfigurationProperties(prefix = "zhongyan.tenant.default")
public class TenantProperties {

    /**
     * 企业id
     */
    public static Long tenantId = 111L;

    /**
     * 企业名称
     */
    public static String name = "浙江中烟";

    /**
     * 注册日期
     */
    public static String signDate = "2021-01-01";

    /**
     * 默认密码
     */
    public static String password = "zhongyan123";
    /**
     * 新默认初始密码
     */
    public static String defaultPassword = "zhongyan@123";

    /**
     * 登录cookie秘钥
     */
    public static String keyEncrypt = "lxk5vo1dndcz";

    /**
     * cookie名称
     */
    public static String cookieName = "manage-tku";

    /**
     * 一级域名
     */
    public static String domain = "";

    public void setTenantId(Long tenantId) {
        TenantProperties.tenantId = tenantId;
    }

    public void setName(String name) {
        TenantProperties.name = name;
    }

    public void setSignDate(String signDate) {
        TenantProperties.signDate = signDate;
    }

    public void setPassword(String password) {
        TenantProperties.password = password;
    }

    public static void setDefaultPassword(String defaultPassword) {
        TenantProperties.defaultPassword = defaultPassword;
    }

    public void setKeyEncrypt(String keyEncrypt) {
        TenantProperties.keyEncrypt = keyEncrypt;
    }

    public void setCookieName(String cookieName) {
        TenantProperties.cookieName = cookieName;
    }

    public void setDomain(String domain) {
        TenantProperties.domain = domain;
    }
}
